@@ -8,7 +8,7 @@ except ImportError:
     from io import StringIO
 
 
-__version__ = '0.1.7'
+__version__ = '0.1.8'
 
 
 def format_code(source, summary_wrap_length=0):
@@ -31,7 +31,8 @@ def format_code(source, summary_wrap_length=0):
         end_row, end_column = token[3]
 
         # Preserve escaped newlines
-        if (start_row > last_row and
+        if (not previous_line.lstrip().startswith('#') and
+            start_row > last_row and
                 (previous_line.endswith('\\\n') or
                  previous_line.endswith('\\\r\n') or
                  previous_line.endswith('\\\r'))):
@@ -184,14 +185,14 @@ def detect_encoding(filename):
 def main(argv, standard_out):
     """Main entry point."""
     import argparse
-    parser = argparse.ArgumentParser(description=__doc__, prog=argv[0])
+    parser = argparse.ArgumentParser(description=__doc__, prog='docformatter')
     parser.add_argument('--in-place', action='store_true',
                         help='make changes to files instead of printing diffs')
     parser.add_argument('--no-backup', dest='backup', action='store_false',
                         help='do not write backup files')
     parser.add_argument(
         '--wrap-long-summaries', default=0, type=int, metavar='LENGTH',
-        help='wrap long summary lines at this length (default: 0)')
+        help='wrap long summary lines at this length (default: %(default)s)')
     parser.add_argument('--version', action='version', version=__version__)
     parser.add_argument('files', nargs='+',
                         help='files to format')
